/* 
 * Copyright (C) 2006 Registro.br. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 1. Redistribution of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY REGISTRO.BR ``AS IS AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIE OF FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL REGISTRO.BR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */
/* $Id: BrDomainCreate.cpp 756 2006-06-09 17:42:34Z koji $ */

#include "BrDomainCreate.H"
#include "StrUtil.H"
#include "libepp_nicbr.H"

LIBEPP_NICBR_NS_BEGIN

void BrDomainCreate::set_xml_template(const string &xml_template)
{
  StrUtil su;
  DomainCreate::set_xml_template(xml_template);

  map < string, string, less<string> > to_parse;

  // organization
  to_parse["organization"] =
    su.esc_xml_markup(get_command()->get_organization());

  // releaseProcessFlags
  to_parse["releaseProcessFlags"] = "";
  ReleaseProcessFlags rpf = get_command()->get_releaseProcessFlags();
  if (rpf.flag1 == 1 || rpf.flag2 == 1 || rpf.flag3 == 1) {
    to_parse["releaseProcessFlags"] = "<brdomain:releaseProcessFlags";

    if (rpf.flag1 == 1) {
      to_parse["releaseProcessFlags"] += " flag1='1'";
    }
    
    if (rpf.flag2 == 1) {
      to_parse["releaseProcessFlags"] += " flag2='1'";
    }

    if (rpf.flag3 == 1) {
      to_parse["releaseProcessFlags"] += " flag3='1'";
    }
    to_parse["releaseProcessFlags"] += "/>";
  }
  
  int active = get_command()->get_active();
  if(active == 0 || active == 1)
    to_parse["autoRenew"] = "<brdomain:autoRenew active=\"" + 
      StrUtil::to_string("%d", active) + "\"/>";
  else
    to_parse["autoRenew"] = "";

  _xml = StrUtil::parse(_xml, to_parse, "$(", ")$");
}

LIBEPP_NICBR_NS_END
